require 'faraday'
require 'faraday_middleware'
require 'listo/middleware/raise_error'

module Listo
  class Connection < SimpleDelegator
    def initialize(token, debug_mode: false)
      @debug_mode = debug_mode

      connection = Faraday.new(url: url) do |faraday|
        faraday.use Listo::Middleware::RaiseError

        faraday.request  :json
        faraday.response :json, content_type: 'application/json'

        faraday.adapter Faraday.default_adapter
      end

      connection.headers['Authorization'] = "Token #{token}"
      connection.headers['Content-Type']  = 'application/json'
      connection.headers['Accept']        = 'application/json'

      super(connection)
    end

    private

      def url
        @debug_mode ? 'https://staging.listo.mx/api' : 'https://listo.mx/api'
      end
  end
end
